@@ -92,7 +92,7 @@ def get_version_from_git():
     for opts in [["--first-parent"], []]:
         try:
             p = subprocess.Popen(
-                ["git", "describe", "--long", "--always"] + opts,
+                ["git", "describe", "--long", "--always", "--tags"] + opts,
                 cwd=distr_root,
                 stdout=subprocess.PIPE,
                 stderr=subprocess.PIPE,
@@ -180,7 +180,7 @@ def _write_version(fname):
         os.remove(fname)
     except OSError:
         pass
-    with open(fname, "w") as f:
+    with open(fname, "w", encoding="utf-8") as f:
         f.write(
             "# This file has been created by setup.py.\n"
             "version = '{}'\n".format(__version__)
